==> Hyper-MPI_1.3.1_aarch64_OpenEuler22.03SP2_GCC10.3.1_MLNX-OFED5.8.tar.gz: Hyper-MPI_1.3.1_aarch64_OpenEuler22.03SP2_GCC10.3.1_MLNX-OFED5.8/ompi/include/openmpi/opal/version.h <==
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2005 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2011 Cisco Systems, Inc.  All rights reserved.
 * Copyright (c) 2016      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 *
 * This file should be included by any file that needs full
 * version information for the OPAL project
 */

#ifndef OPAL_VERSIONS_H
#define OPAL_VERSIONS_H

#define OPAL_MAJOR_VERSION 4
#define OPAL_MINOR_VERSION 1
#define OPAL_RELEASE_VERSION 1
#define OPAL_GREEK_VERSION "rc4"
#define OPAL_WANT_REPO_REV @OPAL_WANT_REPO_REV@
#define OPAL_REPO_REV "v1.3.1.spc001-huawei"
#ifdef OPAL_VERSION
/* If we included version.h, we want the real version, not the
   stripped (no-r number) verstion */
#undef OPAL_VERSION
#endif
#define OPAL_VERSION "4.1.1rc4"
#define OPAL_CONFIGURE_CLI " \'--prefix=/opt/agent_1703063329686/workspace/j_mLe8U3KC/hmpi/build/../bin\' \'--disable-picky\' \'--with-platform=contrib/platform/mellanox/optimized\' \'--enable-mpi1-compatibility\' \'--with-ucx=/opt/agent_1703063329686/workspace/j_mLe8U3KC/hmpi/build/../3rdparty/ucx/\' \'--with-pic\' \'CFLAGS=-fstack-protector-strong -fPIE -pie\' \'CXXFLAGS=-fstack-protector-strong -fPIE -pie\' \'LDFLAGS=-Wl,-z,relro,-z,now,-z,noexecstack,-s\'"

#endif

==> Hyper-MPI_2.3.0_aarch64_OpenEuler22.03SP2_GCC10.3.1_MLNX-OFED5.8.tar.gz: Hyper-MPI_2.3.0_aarch64_OpenEuler22.03SP2_GCC10.3.1_MLNX-OFED5.8/ompi/include/openmpi/opal/version.h <==
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2005 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2011 Cisco Systems, Inc.  All rights reserved.
 * Copyright (c) 2016      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 *
 * This file should be included by any file that needs full
 * version information for the OPAL project
 */

#ifndef OPAL_VERSIONS_H
#define OPAL_VERSIONS_H

#define OPAL_MAJOR_VERSION 4
#define OPAL_MINOR_VERSION 1
#define OPAL_RELEASE_VERSION 1
#define OPAL_GREEK_VERSION "rc4"
#define OPAL_WANT_REPO_REV @OPAL_WANT_REPO_REV@
#define OPAL_REPO_REV "v2.3.0-huawei"
#ifdef OPAL_VERSION
/* If we included version.h, we want the real version, not the
   stripped (no-r number) verstion */
#undef OPAL_VERSION
#endif
#define OPAL_VERSION "4.1.1rc4"
#define OPAL_CONFIGURE_CLI " \'--prefix=/opt/agent_1711975116314/workspace/j_s82HFNed/hmpi/build/../bin\' \'--disable-picky\' \'--with-platform=contrib/platform/mellanox/optimized\' \'--enable-mpi1-compatibility\' \'--with-ucx=/opt/agent_1711975116314/workspace/j_s82HFNed/hmpi/build/../3rdparty/ucx/\' \'--with-pic\' \'CFLAGS=-fstack-protector-strong -fPIE -pie\' \'CXXFLAGS=-fstack-protector-strong -fPIE -pie\' \'LDFLAGS=-Wl,-z,relro,-z,now,-z,noexecstack,-s\'"

#endif
